@@ -351,7 +351,7 @@ vertically."
   'center
   "title string horizontal alignment"
   :tooltip "'real-center' means to take the whole titlebar into \
-account while centering the string. when selecting 'center' only the \
+account while centering the string. When selecting 'center' only the \
 distance between the buttons is taken into account."
   :group (appearance mxflat:group mxflat:title-group mxflat:title-basic-group)
   :type symbol
@@ -475,7 +475,7 @@ degress around the color cycle...180 for example inverts the color"
 
 (defcustom mxflat:color-saturation
   50
-  "unfocused/highlighted titlebar colors saturation (0 - 100% of the \
+  "unfocused/highlighted titlebar colors saturation (0 - 100 percent of the \
 focused color)"
   :tooltip "The saturation of a color is a measurement of the color \
 intensity"
@@ -487,7 +487,7 @@ intensity"
 
 (defcustom mxflat:color-brightness
   90
-  "unfocused/highlighted titlebar colors brightness (0 - 100% of the \
+  "unfocused/highlighted titlebar colors brightness (0 - 100 percent of the \
 focused color)"
   :group (appearance mxflat:group mxflat:title-group
                      mxflat:title-gradient-group)
@@ -728,7 +728,7 @@ button will be drawn on left/right side of the titlebar."
   'title-height
   "button position model"
   :tooltip "'title-height' means calculate position as multiple of \
-title height. when selecting 'pixel' you can adjust the button \
+title height. When selecting 'pixel' you can adjust the button \
 position pixelwise, but keep in mind that several buttons might \
 slide on top of each other. 'none' means no buttons at all."
   :group (appearance mxflat:group mxflat:buttons-group
@@ -995,7 +995,7 @@ Button1: sets window depth to the adjusted value."
 
 (defcustom mxflat:customize-lock-keymap
   nil
-  "customize look button keymap"
+  "customize lock button keymap"
   :tooltip "By default a button will work as it's name suggests. \
 Button1: lock window position"
   :group (appearance mxflat:group mxflat:buttons-group
@@ -2732,45 +2732,11 @@ string color."
 ;;; REGISTER THEME
 ;;  --------------
 ;;
-;; that is from the manual
-;; (http://sawmill.sourceforge.net/prog-manual.html)
-;;
-;; Frame Types
-;;
-;; * default
-;; The normal frame type. Includes all decorations, both borders and
-;; the title bar.
-;;
-;; * transient
-;; The frame for a transient window. This usually does not include a
-;; title bar, but does have all four borders.
-;;
-;; * shaped
-;; Shaped windows are normally decorated with only a title-bar, since
-;; their boundary is not rectangular it makes no sense to surround
-;; them with a rectangular border.
-;;
-;; * shaped-transient
-;; A combination of the shaped and transient types, normally just a
-;; very small title border with no text.
-;;
-;; * shaded
-;; A shaded window (normally just the title bar).
-;;
-;; * shaded-transient
-;; A shaded transient window.
-;;
-;; * unframed
-;; No frame at all, just the client window itself. The predefined
-;; nil-frame variable contains a null frame that may be used for this
-;; frame type.
-;;
 ;; "Normal" 'default
 ;; "Title-only" 'shaped
 ;; "Border-only" 'transient
 ;; "Top-border" 'shaped-transient
 ;; "None" 'unframed
-;;
 
 ;; return the window frame and decorations
 (define (get-frame w frame-type)
